CORE DEVELOPERS
===============

* Chris Glass (chrisglass)
* Martin Brochhaus

CONTRIBUTORS
============

* fivethreeo
* Jonas Obrist
* Issac Kelly
* Audrey Roy
* Raúl Cumplido
* Bojan Mihelac
* Rolo Mawlabaux
* Justin Steward 
* Kristian Øllegaard
* Martin Ogden
* Pavel Zhukov

TRANSLATORS
===========

* Pedro Gracia (Spanish)
* Pavel Zhukov (Russian)
